==> spip_3.0.8.orig.tar.xz: spip-3.0.8.orig/plugins-dist/mots/lang/mots_lb.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/mots?lang_cible=lb
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Wichtege Grupp:</b> et ass wierklech ubruecht e Schlësselwuert aus dësem Grupp ze wielen.',
	'avis_doublon_mot_cle' => 'Et gëtt schon e Schlësselwuert mat deem Titel. Sidd dir sécher dat dir de selwechten wëllt bäiflécken?',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'd\'Administrateure vum Site',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'd\'Redakteren',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'd\'Visiteure vum Site, wann se e Message an de Forum schécken.',

	// C
	'creer_et_associer_un_mot' => 'Schlësselwuert bäiflécken an ubannen',

	// I
	'icone_creation_groupe_mots' => 'E Schlësselwierder-Grupp bäiflécken',
	'icone_creation_mots_cles' => 'E Schlësselwuert bäiflécken',
	'icone_modif_groupe_mots' => 'Dëse Schlësselwierder-Grupp änneren',
	'icone_modifier_mot' => 'Dëst Schlësselwuert änneren',
	'icone_mots_cles' => 'Schlësselwierder',
	'icone_supprimer_groupe_mots' => 'Dëse Grupp läschen',
	'icone_voir_groupe_mots' => 'Dëse Grupp weisen',
	'icone_voir_tous_mots_cles' => 'All d\'Schlësselwierder weisen',
	'info_1_groupe_mots' => '1 Grupp',
	'info_articles_lies_mot' => 'Artikelen déi un dëst Schlësselwuert gebonnen sinn',
	'info_aucun_groupe_mots' => 'Kee Grupp',
	'info_aucun_mot_cle' => 'Kee Schlësselwuert',
	'info_changer_nom_groupe' => 'Numm vun dësem Grupp änneren:',
	'info_creation_mots_cles' => 'Fléckt hei d\'Schlësselwierder vum Site bäi a stellt se an',
	'info_dans_groupe' => 'Am Grupp:',
	'info_delet_mots_cles' => 'Dir wëllt d\'Schlësselwuert <b>@titre_mot@</b> (@type_mot@) läschen. Dëst Wuert ass un <b>@texte_lie@</b> gebonnen, dir musst dës Decisioun bestätegen:',
	'info_groupe_important' => 'Wichtege Grupp',
	'info_modifier_mot' => 'Schlësselwuert änneren:',
	'info_mots_cles' => 'D\'Schlësselwierder',
	'info_mots_cles_association' => 'D\'Schlësselwierder vun dësem Grupp kënnen verbonne ginn:',
	'info_nb_groupe_mots' => '@nb@ Gruppen',
	'info_oui_suppression_mot_cle' => 'ech wëll dëst Schlësselwuert definitiv läschen.',
	'info_question_mots_cles' => 'Wëllt dir Schlësselwierder op ärem Site benotzen?',
	'info_qui_attribue_mot_cle' => 'D\'Schlësselwierder vun dësem Grupp kënne verdeelt gi vun:',
	'info_remplacer_mot' => '"@titre@" ersetzen',
	'info_retirer_mot' => 'Dëst Schlësselwuert läschen',
	'info_retirer_mots' => 'All Schlësselwierder läschen',
	'info_rubriques_liees_mot' => 'Rubriken déi un dëst Schlësselwuert gebonne sinn',
	'info_selection_un_seul_mot_cle' => 'Dir kënnt <b>ëmmer nëmmen 1 Schlësselwuert</b> aus dësem Grupp wielen.',
	'info_supprimer_mot' => 'dëst Schlësselwuert läschen',
	'info_titre_mot_cle' => 'Numm oder Titel vum Schlësselwuert',
	'info_un_mot' => 'E Wuert nom aneren',
	'item_ajout_mots_cles' => 'Schlësselwierder an de Forumen erlaben',
	'item_non_ajout_mots_cles' => 'D\'Schlësselwierder an de Forume verbidden',
	'item_non_utiliser_config_groupe_mots_cles' => 'Déi erweidert Astellung vun de Schlësselwierder ausschalten',
	'item_non_utiliser_mots_cles' => 'D\'Schlësselwierder ausschalten',
	'item_utiliser_config_groupe_mots_cles' => 'Déi erweidert Astellung vun de Schlësselwierder aschalten',
	'item_utiliser_mots_cles' => 'D\'Schlësselwierder aschalten',

	// L
	'lien_ajouter_mot' => 'Dëst Schlësselwuert bäiflécken',
	'logo_groupe' => 'LOGO VUN DËSEM GRUPP',
	'logo_mot_cle' => 'LOGO VUM SCHLËSSELWUERT',

	// T
	'texte_config_groupe_mots_cles' => 'Wëll dir déi erweidert Astellung vun de Schlësselwierder aschalten (z.B. uginn dat nëmmen 1 Wuert pro Grupp kann ausgewielt ginn, dat e Grupp wichteg ass, asw.)?',
	'texte_mots_cles' => 'D\'Schlësselwierder erlaben thematesch Linken tëschent Artikelen ze maachen, egal a wéi enger Rubrik se sinn. Dir kënnt esou är Navigatioun vum Site erweideren, oder dëst benotzen fir de Layout vun den Artikelen an de Skeletter unzepassen.',
	'texte_mots_cles_dans_forum' => 'Wëllt dir erlaben dat d\'Visiteure vum Site an den ëffentleche Forumen Schlësselwierder kënnen auswielen? (Opgepasst: dës Fonctioun ass zimlech schwéier richteg ze benotzen.)',
	'texte_nouveau_mot' => 'Neit Schlësselwuert',
	'titre_config_groupe_mots_cles' => 'Astelle vun de Schlësselwierder-Gruppen',
	'titre_gauche_mots_edit' => 'SCHLËSSELWUERT NUMMER:',
	'titre_groupe_mots' => 'SCHLËSSELWUERT-GRUPP:',
	'titre_groupe_mots_numero' => 'SCHLËSSELWUERT-GRUPP NUMMER:',
	'titre_groupes_mots' => 'Schlësselwieder-Gruppen',
	'titre_mots_cles_dans_forum' => 'Schlësselwierder an de Forume vum ëffentlechen Site',
	'titre_mots_tous' => 'D\'Schlësselwierder',
	'titre_nouveau_groupe' => 'Neie Grupp',
	'titre_objets_lies_mot' => 'Mat dësem Schlësselwuert verbonnen:',
	'titre_page_mots_tous' => 'Schlësselwierder'
);

?>

==> spip_3.0.11.orig.tar.xz: spip-3.0.11.orig/plugins-dist/mots/lang/mots_lb.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/mots?lang_cible=lb
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Wichtege Grupp:</b> et ass wierklech ubruecht e Schlësselwuert aus dësem Grupp ze wielen.',
	'avis_doublon_mot_cle' => 'Et gëtt schon e Schlësselwuert mat deem Titel. Sidd dir sécher dat dir de selwechten wëllt bäiflécken?', # MODIF

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'd\'Administrateure vum Site',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'd\'Redakteren',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'd\'Visiteure vum Site, wann se e Message an de Forum schécken.',

	// C
	'creer_et_associer_un_mot' => 'Schlësselwuert bäiflécken an ubannen',

	// I
	'icone_creation_groupe_mots' => 'E Schlësselwierder-Grupp bäiflécken',
	'icone_creation_mots_cles' => 'E Schlësselwuert bäiflécken',
	'icone_modif_groupe_mots' => 'Dëse Schlësselwierder-Grupp änneren',
	'icone_modifier_mot' => 'Dëst Schlësselwuert änneren',
	'icone_mots_cles' => 'Schlësselwierder',
	'icone_supprimer_groupe_mots' => 'Dëse Grupp läschen',
	'icone_voir_groupe_mots' => 'Dëse Grupp weisen',
	'icone_voir_tous_mots_cles' => 'All d\'Schlësselwierder weisen',
	'info_1_groupe_mots' => '1 Grupp',
	'info_articles_lies_mot' => 'Artikelen déi un dëst Schlësselwuert gebonnen sinn',
	'info_aucun_groupe_mots' => 'Kee Grupp',
	'info_aucun_mot_cle' => 'Kee Schlësselwuert',
	'info_changer_nom_groupe' => 'Numm vun dësem Grupp änneren:',
	'info_creation_mots_cles' => 'Fléckt hei d\'Schlësselwierder vum Site bäi a stellt se an',
	'info_dans_groupe' => 'Am Grupp:',
	'info_delet_mots_cles' => 'Dir wëllt d\'Schlësselwuert <b>@titre_mot@</b> (@type_mot@) läschen. Dëst Wuert ass un <b>@texte_lie@</b> gebonnen, dir musst dës Decisioun bestätegen:',
	'info_groupe_important' => 'Wichtege Grupp',
	'info_modifier_mot' => 'Schlësselwuert änneren:',
	'info_mots_cles' => 'D\'Schlësselwierder',
	'info_mots_cles_association' => 'D\'Schlësselwierder vun dësem Grupp kënnen verbonne ginn:',
	'info_nb_groupe_mots' => '@nb@ Gruppen',
	'info_oui_suppression_mot_cle' => 'ech wëll dëst Schlësselwuert definitiv läschen.',
	'info_question_mots_cles' => 'Wëllt dir Schlësselwierder op ärem Site benotzen?',
	'info_qui_attribue_mot_cle' => 'D\'Schlësselwierder vun dësem Grupp kënne verdeelt gi vun:',
	'info_remplacer_mot' => '"@titre@" ersetzen',
	'info_retirer_mot' => 'Dëst Schlësselwuert läschen',
	'info_retirer_mots' => 'All Schlësselwierder läschen',
	'info_rubriques_liees_mot' => 'Rubriken déi un dëst Schlësselwuert gebonne sinn',
	'info_selection_un_seul_mot_cle' => 'Dir kënnt <b>ëmmer nëmmen 1 Schlësselwuert</b> aus dësem Grupp wielen.',
	'info_supprimer_mot' => 'dëst Schlësselwuert läschen',
	'info_titre_mot_cle' => 'Numm oder Titel vum Schlësselwuert',
	'info_un_mot' => 'E Wuert nom aneren',
	'item_ajout_mots_cles' => 'Schlësselwierder an de Forumen erlaben',
	'item_non_ajout_mots_cles' => 'D\'Schlësselwierder an de Forume verbidden',
	'item_non_utiliser_config_groupe_mots_cles' => 'Déi erweidert Astellung vun de Schlësselwierder ausschalten',
	'item_non_utiliser_mots_cles' => 'D\'Schlësselwierder ausschalten',
	'item_utiliser_config_groupe_mots_cles' => 'Déi erweidert Astellung vun de Schlësselwierder aschalten',
	'item_utiliser_mots_cles' => 'D\'Schlësselwierder aschalten',

	// L
	'lien_ajouter_mot' => 'Dëst Schlësselwuert bäiflécken',
	'logo_groupe' => 'LOGO VUN DËSEM GRUPP',
	'logo_mot_cle' => 'LOGO VUM SCHLËSSELWUERT',

	// T
	'texte_config_groupe_mots_cles' => 'Wëll dir déi erweidert Astellung vun de Schlësselwierder aschalten (z.B. uginn dat nëmmen 1 Wuert pro Grupp kann ausgewielt ginn, dat e Grupp wichteg ass, asw.)?',
	'texte_mots_cles' => 'D\'Schlësselwierder erlaben thematesch Linken tëschent Artikelen ze maachen, egal a wéi enger Rubrik se sinn. Dir kënnt esou är Navigatioun vum Site erweideren, oder dëst benotzen fir de Layout vun den Artikelen an de Skeletter unzepassen.',
	'texte_mots_cles_dans_forum' => 'Wëllt dir erlaben dat d\'Visiteure vum Site an den ëffentleche Forumen Schlësselwierder kënnen auswielen? (Opgepasst: dës Fonctioun ass zimlech schwéier richteg ze benotzen.)',
	'texte_nouveau_mot' => 'Neit Schlësselwuert',
	'titre_config_groupe_mots_cles' => 'Astelle vun de Schlësselwierder-Gruppen',
	'titre_gauche_mots_edit' => 'SCHLËSSELWUERT NUMMER:',
	'titre_groupe_mots' => 'SCHLËSSELWUERT-GRUPP:',
	'titre_groupe_mots_numero' => 'SCHLËSSELWUERT-GRUPP NUMMER:',
	'titre_groupes_mots' => 'Schlësselwieder-Gruppen',
	'titre_mots_cles_dans_forum' => 'Schlësselwierder an de Forume vum ëffentlechen Site',
	'titre_mots_tous' => 'D\'Schlësselwierder',
	'titre_nouveau_groupe' => 'Neie Grupp',
	'titre_objets_lies_mot' => 'Mat dësem Schlësselwuert verbonnen:',
	'titre_page_mots_tous' => 'Schlësselwierder'
);

?>
